==> PoweR_1.0.tar.gz: PoweR/man/Laplace.tests.Rd <==
\name{Laplace.tests}

\alias{Laplace.tests}

\title{Goodness-of-fit tests for the Laplace distribution}

\description{List of goodness-of-fit tests for the Laplace distribution.
}

\details{The statistic tests for the Laplace distribution are names in
  the form \code{stat}\eqn{xxxx}.

For the Anderson-Darling statistic see \code{\link{stat0042.AndersonDarling}}.

For the Cramer-von Mises statistic see \code{\link{stat0043.CramervonMises}}.

For the Watson statistic see \code{\link{stat0044.Watson}}.

For the Kolmogorov-Smirnov statistic see \code{\link{stat0045.KolmogorovSmirnov}}.

For the Kuiper statistic see \code{\link{stat0046.Kuiper}}.

For the 1st Meintanis statistic with moment estimators see \code{\link{stat0047.Meintanis1MO}}.

For the 1st Meintanis statistic with maximum likelihood estimators see \code{\link{stat0048.Meintanis1ML}}.

For the 2nd Meintanis statistic with moment estimators see \code{\link{stat0049.Meintanis2MO}}.

For the 2nd Meintanis statistic with maximum likelihood estimators see \code{\link{stat0050.Meintanis2ML}}.

For the 1st Choi-Kim statistic see \code{\link{stat0051.ChoiKim1}}.

For the 2nd Choi-Kim statistic see \code{\link{stat0052.ChoiKim2}}.

For the 3rd Choi-Kim statistic see \code{\link{stat0053.ChoiKim3}}.

For the Desgagne-Micheaux-Leblanc statistic see \code{\link{stat0054.DesgagneMicheauxLeblanc-Gn}}.

For the 1st Rayner-Best statistic see \code{\link{stat0055.RaynerBest1}}.

For the 2nd Rayner-Best statistic see \code{\link{stat0056.RaynerBest2}}.

For the Langholz-Kronmal statistic see \code{\link{stat0057.LangholzKronmal}}.

For the Kundu statistic see \code{\link{stat0058.Kundu}}.

For the Gulati statistic see \code{\link{stat0059.Gulati}}.

For the Gel statistic see \code{\link{stat0060.Gel}}.

}

\references{
Lafaye de Micheaux, P. and Tran, V. A. (2014), PoweR: Reproducible
Research Tool to ease Monte-Carlo Power Simulation Studies for
Goodness-of-fit Tests in R. \emph{Journal of Statistical Software}, \bold{}, --. 
}
\author{P. Lafaye de Micheaux, V. A. Tran}

\seealso{See \code{\link{Normality.tests}} for goodness-of-fit tests for
  normality. See \code{\link{Uniformity.tests}} for goodness-of-fit tests for uniformity.
}
\keyword{documentation}

==> PoweR_1.0.4.tar.gz: PoweR/man/Laplace.tests.Rd <==
\name{Laplace.tests}

\alias{Laplace.tests}

\title{Goodness-of-fit tests for the Laplace distribution}

\description{List of goodness-of-fit tests for the Laplace distribution.
}

\details{The statistic tests for the Laplace distribution are named in
  the form \code{stat}\eqn{xxxx}.

For the Anderson-Darling statistic see \code{\link{stat0042.AndersonDarling}}.

For the Cramer-von Mises statistic see \code{\link{stat0043.CramervonMises}}.

For the Watson statistic see \code{\link{stat0044.Watson}}.

For the Kolmogorov-Smirnov statistic see \code{\link{stat0045.KolmogorovSmirnov}}.

For the Kuiper statistic see \code{\link{stat0046.Kuiper}}.

For the 1st Meintanis statistic with moment estimators see \code{\link{stat0047.Meintanis1MO}}.

For the 1st Meintanis statistic with maximum likelihood estimators see \code{\link{stat0048.Meintanis1ML}}.

For the 2nd Meintanis statistic with moment estimators see \code{\link{stat0049.Meintanis2MO}}.

For the 2nd Meintanis statistic with maximum likelihood estimators see \code{\link{stat0050.Meintanis2ML}}.

For the 1st Choi-Kim statistic see \code{\link{stat0051.ChoiKim1}}.

For the 2nd Choi-Kim statistic see \code{\link{stat0052.ChoiKim2}}.

For the 3rd Choi-Kim statistic see \code{\link{stat0053.ChoiKim3}}.

For the Desgagne-Micheaux-Leblanc statistic see \code{\link{stat0054.DesgagneMicheauxLeblanc-Gn}}.

For the 1st Rayner-Best statistic see \code{\link{stat0055.RaynerBest1}}.

For the 2nd Rayner-Best statistic see \code{\link{stat0056.RaynerBest2}}.

For the Langholz-Kronmal statistic see \code{\link{stat0057.LangholzKronmal}}.

For the Kundu statistic see \code{\link{stat0058.Kundu}}.

For the Gulati statistic see \code{\link{stat0059.Gulati}}.

For the Gel statistic see \code{\link{stat0060.Gel}}.

}

\references{
Lafaye de Micheaux, P. and Tran, V. A. (2014), PoweR: Reproducible
Research Tool to ease Monte-Carlo Power Simulation Studies for
Goodness-of-fit Tests in R. \emph{Journal of Statistical Software}, \bold{}, --. 
}
\author{P. Lafaye de Micheaux, V. A. Tran}

\seealso{See \code{\link{Normality.tests}} for goodness-of-fit tests for
  normality. See \code{\link{Uniformity.tests}} for goodness-of-fit tests for uniformity.
}
\keyword{documentation}
